# ✉️💣🌐 LetterBomb Web

<div align="center">

### A flask module that complements the letterbomb API.

[![CI/CD](https://img.shields.io/gitlab/pipeline/whoatemybutter/letterbomb_web/master?label=ci%2Fcd)](https://gitlab.com/whoatemybutter/letterbomb/-/pipelines)
[![PyPI downloads](https://img.shields.io/pypi/dd/letterbomb_web)](https://pypi.org/project/letterbomb)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Pylint](https://img.shields.io/badge/pylint-10.00/10-ffbf48)](https://pylint.pycqa.org/en/latest/)
[![License](https://img.shields.io/badge/license-MIT-a51931)](https://spdx.org/licenses/MIT.html)
[![PyPI version](https://img.shields.io/pypi/v/letterbomb_web)](https://pypi.org/project/letterbomb/)
[![GitLab version](https://img.shields.io/gitlab/v/release/51583324?sort=semver)](https://gitlab.com/whoatemybutter/letterbomb_web/-/releases)

<a href="https://gitlab.com/whoatemybutter/letterbomb_web"><img src="assets/letterbomb_web.png" width="250" align="center"/></a>

</div>

---

## Table of Contents

- [Installation](#installation)
    - [PyPI](#pypi-recommended)
    - [Manual](#manual-web-server-development)
- [Usage](#usage)
- [License](#license)

## Installation

#### [PyPI](https://pypi.org/project/letterbomb): **(recommended)**
```shell script
python3 -m pip install -U letterbomb_web
```

#### Manual: **(web server, development)**
```shell script
git clone https://gitlab.com/whoatemybutter/letterbomb_web.git
cd letterbomb_web
python -m build
```

## Usage

Refer to [the documentation](https://letterbomb.readthedocs.io/en/latest/web.html).

## License

LetterBomb Web is licensed under the [MIT license](https://mit-license.org/). ([included file](https://gitlab.com/whoatemybutter/letterbomb/-/raw/master/LICENSE.txt))
